mdt\.gui\.model\_fit\.design package
====================================

Submodules
----------

mdt\.gui\.model\_fit\.design\.main\_gui\_rc module
--------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.main_gui_rc
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_about\_dialog module
------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_about_dialog
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_dialog\_get\_example\_data module
-------------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_dialog_get_example_data
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_fit\_model\_tab module
--------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_fit_model_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_generate\_brain\_mask\_tab module
-------------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_generate_brain_mask_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_generate\_protocol\_load\_gb\_dialog module
-----------------------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_generate_protocol_load_gb_dialog
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_generate\_protocol\_tab module
----------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_generate_protocol_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_generate\_protocol\_update\_dialog module
---------------------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_generate_protocol_update_dialog
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_generate\_roi\_mask\_tab module
-----------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_generate_roi_mask_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_main\_gui module
--------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_main_gui
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_optimization\_extra\_data\_add\_protocol\_map\_dialog module
----------------------------------------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_optimization_extra_data_add_protocol_map_dialog
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_optimization\_extra\_data\_dialog module
--------------------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_optimization_extra_data_dialog
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_optimization\_options\_dialog module
----------------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_optimization_options_dialog
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.design\.ui\_runtime\_settings\_dialog module
------------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_runtime_settings_dialog
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mdt.gui.model_fit.design
    :members:
    :undoc-members:
    :show-inheritance:
